[Rt-commit] r10563 - rt/branches/3.999-DANGEROUS/lib/RT/Model
ruz at bestpractical.com
ruz at bestpractical.com
Tue Jan 29 17:41:27 EST 2008
Author: ruz
Date: Tue Jan 29 17:41:27 2008
New Revision: 10563
Modified:
rt/branches/3.999-DANGEROUS/lib/RT/Model/ACE.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Attachment.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/CachedGroupMember.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomField.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomFieldValue.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Group.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/GroupMember.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Link.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomField.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomFieldValue.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Principal.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Queue.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Scrip.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripAction.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripCondition.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/TemplateCollection.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/TicketCollection.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm
rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm
Log:
* conversion of calls and schemas in models
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/ACE.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/ACE.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/ACE.pm Tue Jan 29 17:41:27 2008
@@ -86,8 +86,8 @@
object_type => max_length is 25,
type is 'varchar(25)', default is '';
column object_id => type is 'int(11)', default is '0';
- column DelegatedBy => type is 'int(11)', default is '0';
- column DelegatedFrom => type is 'int(11)', default is '0';
+ column delegated_by => type is 'int(11)', default is '0';
+ column delegated_from => type is 'int(11)', default is '0';
};
use vars qw (
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Attachment.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Attachment.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Attachment.pm Tue Jan 29 17:41:27 2008
@@ -35,24 +35,24 @@
transaction_id => max_length is 11,
type is 'int(11)', default is '0';
column
- MessageId => max_length is 200,
+ message_id => max_length is 200,
type is 'varchar(200)', default is '';
column parent => max_length is 11, type is 'int(11)', default is '0';
column
content_type => max_length is 200,
type is 'varchar(200)', default is '';
column
- Filename => max_length is 255,
+ filename => max_length is 255,
type is 'varchar(255)', default is '';
column
subject => max_length is 255,
type is 'varchar(255)', default is '';
column content => type is 'blob', default is '';
- column ContentEncoding => type is 'blob', default is '';
- column Headers => type is 'blob', default is '';
- column Creator => max_length is 11, type is 'int(11)', default is '0';
- column Created => type is 'datetime';
+ column content_encoding => type is 'blob', default is '';
+ column headers => type is 'blob', default is '';
+ column creator => max_length is 11, type is 'int(11)', default is '0';
+ column created => type is 'datetime';
};
@@ -245,7 +245,7 @@
sub content {
my $self = shift;
- return $self->_decode_lob( $self->content_type, $self->ContentEncoding,
+ return $self->_decode_lob( $self->content_type, $self->content_encoding,
$self->_value( 'content', decode_utf8 => 0 ),
);
}
@@ -266,16 +266,16 @@
my $enc = $self->original_encoding;
my $content;
- if ( !$self->ContentEncoding || $self->ContentEncoding eq 'none' ) {
+ if ( !$self->content_encoding || $self->content_encoding eq 'none' ) {
$content = $self->_value( 'content', decode_utf8 => 0 );
- } elsif ( $self->ContentEncoding eq 'base64' ) {
+ } elsif ( $self->content_encoding eq 'base64' ) {
$content = MIME::Base64::decode_base64(
$self->_value( 'content', decode_utf8 => 0 ) );
- } elsif ( $self->ContentEncoding eq 'quoted-printable' ) {
+ } elsif ( $self->content_encoding eq 'quoted-printable' ) {
$content = MIME::QuotedPrint::decode(
$self->_value( 'content', decode_utf8 => 0 ) );
} else {
- return ( _( "Unknown ContentEncoding %1", $self->ContentEncoding ) );
+ return ( _( "Unknown ContentEncoding %1", $self->content_encoding ) );
}
# Turn *off* the SvUTF8 bits here so decode_utf8 and from_to below can work.
@@ -594,7 +594,7 @@
my $self = shift;
my $txn = $self->transaction_obj;
- return ( 0, _('Permission Denied') ) unless $txn->current_userCanSee;
+ return ( 0, _('Permission Denied') ) unless $txn->current_user_can_see;
return ( 0, _('Permission Denied') )
unless $txn->ticket_obj->current_user_has_right('ModifyTicket');
return ( 0, _('GnuPG integration is disabled') )
@@ -616,7 +616,7 @@
my $queue = $txn->ticket_obj->queue_obj;
my $encrypt_for;
foreach my $address (
- grep $_, $queue->CorrespondAddress, $queue->CommentAddress,
+ grep $_, $queue->correspond_address, $queue->comment_address,
RT->config->get('CorrespondAddress'),
RT->config->get('CommentAddress'),
)
@@ -658,7 +658,7 @@
my $self = shift;
my $txn = $self->transaction_obj;
- return ( 0, _('Permission Denied') ) unless $txn->current_userCanSee;
+ return ( 0, _('Permission Denied') ) unless $txn->current_user_can_see;
return ( 0, _('Permission Denied') )
unless $txn->ticket_obj->current_user_has_right('ModifyTicket');
return ( 0, _('GnuPG integration is disabled') )
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/CachedGroupMember.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomField.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomField.pm Tue Jan 29 17:41:27 2008
@@ -64,22 +64,22 @@
column name => max_length is 200, type is 'varchar(200)', default is '';
column type => max_length is 200, type is 'varchar(200)', default is '';
- column MaxValues => max_length is 11, type is 'int(11)', default is '0';
- column Pattern => type is 'longtext', default is '';
- column Repeated => max_length is 6, type is 'smallint(6)', default is '0';
+ column max_values => max_length is 11, type is 'int(11)', default is '0';
+ column pattern => type is 'longtext', default is '';
+ column repeated => max_length is 6, type is 'smallint(6)', default is '0';
column
- Description => max_length is 255,
+ description => max_length is 255,
type is 'varchar(255)', default is '';
- column SortOrder => max_length is 11, type is 'int(11)', default is '0';
+ column sort_order => max_length is 11, type is 'int(11)', default is '0';
column
- LookupType => max_length is 255,
+ lookup_type => max_length is 255,
type is 'varchar(255)', default is '';
- column Creator => max_length is 11, type is 'int(11)', default is '0';
- column Created => type is 'datetime', default is '';
+ column creator => max_length is 11, type is 'int(11)', default is '0';
+ column created => type is 'datetime', default is '';
column
- LastUpdatedBy => max_length is 11,
+ last_updated_by => max_length is 11,
type is 'int(11)', default is '0';
- column LastUpdated => type is 'datetime', default is '';
+ column last_updated => type is 'datetime', default is '';
column disabled => max_length is 6, type is 'smallint(6)', default is '0';
};
@@ -170,15 +170,15 @@
varchar(200) 'name'.
varchar(200) 'type'.
- int(11) 'MaxValues'.
- varchar(255) 'Pattern'.
- smallint(6) 'Repeated'.
- varchar(255) 'Description'.
- int(11) 'SortOrder'.
- varchar(255) 'LookupType'.
+ int(11) 'max_values'.
+ varchar(255) 'pattern'.
+ smallint(6) 'repeated'.
+ varchar(255) 'description'.
+ int(11) 'sort_order'.
+ varchar(255) 'lookup_type'.
smallint(6) 'disabled'.
-C<LookupType> is generally the result of either
+C<lookup_type> is generally the result of either
C<RT::Model::Ticket->custom_field_lookup_type> or C<RT::Model::Transaction->custom_field_lookup_type>.
=cut
@@ -188,12 +188,12 @@
my %args = (
name => '',
type => '',
- MaxValues => 0,
- Pattern => '',
- Description => '',
+ max_values => 0,
+ pattern => '',
+ description => '',
disabled => 0,
- LookupType => '',
- Repeated => 0,
+ lookup_type => '',
+ repeated => 0,
@_,
);
@@ -208,11 +208,11 @@
}
if ( $args{TypeComposite} ) {
- @args{ 'type', 'MaxValues' } = split( /-/, $args{TypeComposite}, 2 );
+ @args{ 'type', 'max_values' } = split( /-/, $args{TypeComposite}, 2 );
} elsif ( $args{type} =~ s/(?:(Single)|Multiple)$// ) {
# old style type string
- $args{'MaxValues'} = $1 ? 1 : 0;
+ $args{'max_values'} = $1 ? 1 : 0;
}
if ( !exists $args{'Queue'} ) {
@@ -228,7 +228,7 @@
{
return ( 0, _('Permission Denied') );
}
- $args{'LookupType'} = 'RT::Model::Queue-RT::Model::Ticket';
+ $args{'lookup_type'} = 'RT::Model::Queue-RT::Model::Ticket';
} else {
my $queue = RT::Model::Queue->new;
$queue->load( $args{'Queue'} );
@@ -238,22 +238,22 @@
unless ( $queue->current_user_has_right('AssignCustomFields') ) {
return ( 0, _('Permission Denied') );
}
- $args{'LookupType'} = 'RT::Model::Queue-RT::Model::Ticket';
+ $args{'lookup_type'} = 'RT::Model::Queue-RT::Model::Ticket';
$args{'Queue'} = $queue->id;
}
- my ( $ok, $msg ) = $self->_is_valid_regex( $args{'Pattern'} );
+ my ( $ok, $msg ) = $self->_is_valid_regex( $args{'pattern'} );
return ( 0, _( "Invalid pattern: %1", $msg ) ) unless $ok;
( my $rv, $msg ) = $self->SUPER::create(
name => $args{'name'},
type => $args{'type'},
- MaxValues => $args{'MaxValues'},
- Pattern => $args{'Pattern'},
- Description => $args{'Description'},
+ max_values => $args{'max_values'},
+ pattern => $args{'pattern'},
+ description => $args{'description'},
disabled => $args{'disabled'},
- LookupType => $args{'LookupType'},
- Repeated => $args{'Repeated'},
+ lookup_type => $args{'lookup_type'},
+ repeated => $args{'repeated'},
);
if ( exists $args{'ValuesClass'} ) {
@@ -388,7 +388,7 @@
=head3 AddValue HASH
-Create a new value for this CustomField. Takes a paramhash containing the elements name, Description and SortOrder
+Create a new value for this CustomField. Takes a paramhash containing the elements name, description and sort_order
=cut
@@ -545,7 +545,7 @@
my $self = shift;
my $type = @_ ? shift : $self->type;
- my $max = @_ ? shift : $self->MaxValues;
+ my $max = @_ ? shift : $self->max_values;
$max = 0 unless $max;
if ( my $friendly_type
@@ -577,7 +577,7 @@
if ( $type =~ s/(?:Single|Multiple)$// ) {
Jifty->log->warn(
- "Prefix 'Single' and 'Multiple' to type deprecated, use MaxValues instead at ("
+ "Prefix 'Single' and 'Multiple' to type deprecated, use max_values instead at ("
. join( ":", caller )
. ")" );
}
@@ -597,7 +597,7 @@
"'Single' and 'Multiple' on SetType deprecated, use SetMaxValues instead at ("
. join( ":", caller )
. ")" );
- $self->set_MaxValues( $1 ? 1 : 0 );
+ $self->set_max_values( $1 ? 1 : 0 );
}
$self->_set( column => 'type', value => $type );
}
@@ -605,7 +605,7 @@
=head2 SetPattern STRING
Takes a single string representing a regular expression. Performs basic
-validation on that regex, and sets the C<Pattern> field for the CF if it
+validation on that regex, and sets the C<pattern> field for the CF if it
is valid.
=cut
@@ -616,7 +616,7 @@
my ( $ok, $msg ) = $self->_is_valid_regex($regex);
if ($ok) {
- return $self->set( column => 'Pattern', value => $regex );
+ return $self->set( column => 'pattern', value => $regex );
} else {
return ( 0, _( "Invalid pattern: %1", $msg ) );
}
@@ -658,7 +658,7 @@
sub single_value {
my $self = shift;
- if ( $self->MaxValues == 1 ) {
+ if ( $self->max_values == 1 ) {
return 1;
} else {
return undef;
@@ -667,7 +667,7 @@
sub unlimited_values {
my $self = shift;
- if ( $self->MaxValues == 0 ) {
+ if ( $self->max_values == 0 ) {
return 1;
} else {
return undef;
@@ -765,8 +765,8 @@
my ( $status, $msg ) = $self->set_type($type);
return ( $status, $msg ) unless $status;
}
- if ( ( $max_values || 0 ) != ( $self->MaxValues || 0 ) ) {
- my ( $status, $msg ) = $self->set_MaxValues($max_values);
+ if ( ( $max_values || 0 ) != ( $self->max_values || 0 ) ) {
+ my ( $status, $msg ) = $self->set_max_values($max_values);
return ( $status, $msg ) unless $status;
}
return 1,
@@ -786,14 +786,14 @@
sub set_lookup_type {
my $self = shift;
my $lookup = shift;
- if ( $lookup ne $self->LookupType ) {
+ if ( $lookup ne $self->lookup_type ) {
# Okay... We need to invalidate our existing relationships
my $ObjectCustomFields = RT::Model::ObjectCustomFieldCollection->new;
$ObjectCustomFields->limit_to_custom_field( $self->id );
$_->delete foreach @{ $ObjectCustomFields->items_array_ref };
}
- return $self->_set( column => 'LookupType', value => $lookup );
+ return $self->_set( column => 'lookup_type', value => $lookup );
}
=head2 TypeComposite
@@ -804,7 +804,7 @@
sub type_composite {
my $self = shift;
- return join '-', ( $self->type || '' ), ( $self->MaxValues || 0 );
+ return join '-', ( $self->type || '' ), ( $self->max_values || 0 );
}
=head2 TypeComposites
@@ -842,7 +842,7 @@
sub friendly_lookup_type {
my $self = shift;
- my $lookup = shift || $self->LookupType;
+ my $lookup = shift || $self->lookup_type;
return ( _( $FRIENDLY_OBJECT_TYPES{$lookup} ) )
if ( defined $FRIENDLY_OBJECT_TYPES{$lookup} );
@@ -867,7 +867,7 @@
my $object = shift;
my $id = $object->id || 0;
- unless ( index( $self->LookupType, ref($object) ) == 0 ) {
+ unless ( index( $self->lookup_type, ref($object) ) == 0 ) {
return ( 0, _('Lookup type mismatch') );
}
@@ -899,7 +899,7 @@
my $object = shift;
my $id = $object->id || 0;
- unless ( index( $self->LookupType, ref($object) ) == 0 ) {
+ unless ( index( $self->lookup_type, ref($object) ) == 0 ) {
return ( 0, _('Object type mismatch') );
}
@@ -959,9 +959,9 @@
Jifty->handle->begin_transaction;
- if ( $self->MaxValues ) {
+ if ( $self->max_values ) {
my $current_values = $self->values_for_object($obj);
- my $extra_values = ( $current_values->count + 1 ) - $self->MaxValues;
+ my $extra_values = ( $current_values->count + 1 ) - $self->max_values;
# (The +1 is for the new value we're adding)
@@ -1007,14 +1007,14 @@
=head2 MatchPattern STRING
-Tests the incoming string against the Pattern of this custom field object
-and returns a boolean; returns true if the Pattern is empty.
+Tests the incoming string against the pattern of this custom field object
+and returns a boolean; returns true if the pattern is empty.
=cut
sub match_pattern {
my $self = shift;
- my $regex = $self->Pattern or return 1;
+ my $regex = $self->pattern or return 1;
return ( ( $_[0] || '' ) =~ $regex );
}
@@ -1032,7 +1032,7 @@
sub friendly_pattern {
my $self = shift;
- my $regex = $self->Pattern;
+ my $regex = $self->pattern;
return '' unless length $regex;
if ( $regex =~ /\(\?#([^)]*)\)/ ) {
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomFieldValue.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomFieldValue.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomFieldValue.pm Tue Jan 29 17:41:27 2008
@@ -58,17 +58,17 @@
sub table {'custom_field_values'}
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {
- column Creator => type is 'int(11)', max_length is 11, default is '0';
+ column creator => type is 'int(11)', max_length is 11, default is '0';
column
- LastUpdatedBy => type is 'int(11)',
+ last_updated_by => type is 'int(11)',
max_length is 11, default is '0';
- column SortOrder => type is 'int(11)', max_length is 11, default is '0';
+ column sort_order => type is 'int(11)', max_length is 11, default is '0';
column custom_field => type is 'int(11)', max_length is 11, default is '0';
- column Created => type is 'datetime', default is '';
- column LastUpdated => type is 'datetime', default is '';
+ column created => type is 'datetime', default is '';
+ column last_updated => type is 'datetime', default is '';
column name => type is 'varchar(200)', max_length is 200, default is '';
column
- Description => type is 'varchar(255)',
+ description => type is 'varchar(255)',
max_length is 255, default is '';
};
@@ -85,8 +85,8 @@
my %args = (
custom_field => 0,
name => '',
- Description => '',
- SortOrder => 0,
+ description => '',
+ sort_order => 0,
Category => '',
@_,
);
@@ -107,7 +107,7 @@
my ( $id, $msg ) = $self->SUPER::create(
custom_field => $cf_id,
- map { $_ => $args{$_} } qw(name Description SortOrder)
+ map { $_ => $args{$_} } qw(name description sort_order)
);
return ( $id, $msg ) unless $id;
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Group.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Group.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Group.pm Tue Jan 29 17:41:27 2008
@@ -569,7 +569,7 @@
domain is one of (RT::Model::Ticket-Role || RT::Model::Queue-Role || RT::System-Role)
instance is the id of the ticket or queue in question
-This routine expects to be called from {Ticket||Queue}->createTicket_groups _inside of a transaction_
+This routine expects to be called from {Ticket||Queue}->create_ticket_groups _inside of a transaction_
Returns a tuple of (Id, Message). If id is 0, the create failed
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/GroupMember.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/GroupMember.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/GroupMember.pm Tue Jan 29 17:41:27 2008
@@ -35,8 +35,8 @@
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {
- column GroupId => type is 'integer';
- column MemberId => type is 'integer';
+ column group_id => type is 'integer';
+ column member_id => type is 'integer';
};
@@ -108,8 +108,8 @@
}
my $id = $self->SUPER::create(
- GroupId => $args{'Group'}->id,
- MemberId => $args{'Member'}->id
+ group_id => $args{'Group'}->id,
+ member_id => $args{'Member'}->id
);
unless ($id) {
@@ -135,9 +135,9 @@
$cgm->limit_to_groups_with_member( $args{'Group'}->id );
while ( my $parent_member = $cgm->next ) {
- my $parent_id = $parent_member->MemberId;
+ my $parent_id = $parent_member->member_id;
my $via = $parent_member->id;
- my $group_id = $parent_member->GroupId;
+ my $group_id = $parent_member->group_id;
my $other_cached_member = RT::Model::CachedGroupMember->new;
my $other_cached_id = $other_cached_member->create(
@@ -201,8 +201,8 @@
# cache and bail so we can support cycling directed graphs
my $id = $self->SUPER::create(
- GroupId => $args{'Group'}->id,
- MemberId => $args{'Member'}->id,
+ group_id => $args{'Group'}->id,
+ member_id => $args{'Member'}->id,
);
unless ($id) {
@@ -254,7 +254,7 @@
my $cached_submembers = RT::Model::CachedGroupMemberCollection->new;
$cached_submembers->limit(
- column => 'MemberId',
+ column => 'member_id',
operator => '=',
value => $self->member_obj->id
);
@@ -319,7 +319,7 @@
my $self = shift;
unless ( defined( $self->{'Member_obj'} ) ) {
$self->{'Member_obj'} = RT::Model::Principal->new;
- $self->{'Member_obj'}->load( $self->MemberId ) if ( $self->MemberId );
+ $self->{'Member_obj'}->load( $self->member_id ) if ( $self->member_id );
}
return ( $self->{'Member_obj'} );
}
@@ -330,7 +330,7 @@
=head2 GroupObj
-Returns an RT::Model::Principal object for the Group specified in $self->GroupId
+Returns an RT::Model::Principal object for the Group specified in $self->group_id
=cut
@@ -338,7 +338,7 @@
my $self = shift;
unless ( defined( $self->{'Group_obj'} ) ) {
$self->{'Group_obj'} = RT::Model::Principal->new;
- $self->{'Group_obj'}->load( $self->GroupId );
+ $self->{'Group_obj'}->load( $self->group_id );
}
return ( $self->{'Group_obj'} );
}
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Link.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Link.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Link.pm Tue Jan 29 17:41:27 2008
@@ -75,7 +75,7 @@
sub table {'Links'}
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {
- column Target => type is 'varchar(240)', max_length is 240, default is '';
+ column target => type is 'varchar(240)', max_length is 240, default is '';
column Base => type is 'varchar(240)', max_length is 240, default is '';
column LocalTarget => type is 'int(11)', max_length is 11, default is '0';
column Creator => type is 'int(11)', max_length is 11, default is '0';
@@ -269,7 +269,7 @@
sub target_uri {
my $self = shift;
my $URI = RT::URI->new;
- $URI->from_uri( $self->Target );
+ $URI->from_uri( $self->target );
return ($URI);
}
@@ -298,7 +298,7 @@
sub base_uri {
my $self = shift;
my $URI = RT::URI->new;
- $URI->from_uri( $self->Base );
+ $URI->from_uri( $self->base );
return ($URI);
}
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomField.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomField.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomField.pm Tue Jan 29 17:41:27 2008
@@ -90,7 +90,7 @@
my $ObjectCFs = RT::Model::ObjectCustomFieldCollection->new;
$ObjectCFs->limit_to_object_id( $args{'object_id'} );
$ObjectCFs->limit_to_custom_field( $cf->id );
- $ObjectCFs->limit_to_lookup_type( $cf->LookupType );
+ $ObjectCFs->limit_to_lookup_type( $cf->lookup_type );
if ( my $first = $ObjectCFs->first ) {
$self->load( $first->id );
return $first->id;
@@ -100,10 +100,10 @@
my $ObjectCFs = RT::Model::ObjectCustomFieldCollection->new(
current_user => RT->system_user );
$ObjectCFs->limit_to_object_id( $args{'object_id'} );
- $ObjectCFs->limit_to_lookup_type( $cf->LookupType );
+ $ObjectCFs->limit_to_lookup_type( $cf->lookup_type );
$ObjectCFs->order_by( column => 'SortOrder', order => 'DESC' );
if ( my $first = $ObjectCFs->first ) {
- $args{'SortOrder'} = $first->SortOrder + 1;
+ $args{'SortOrder'} = $first->sort_order + 1;
} else {
$args{'SortOrder'} = 0;
}
@@ -121,14 +121,14 @@
my $ObjectCFs = RT::Model::ObjectCustomFieldCollection->new;
$ObjectCFs->limit_to_object_id( $self->object_id );
- $ObjectCFs->limit_to_lookup_type( $self->custom_field_obj->LookupType );
+ $ObjectCFs->limit_to_lookup_type( $self->custom_field_obj->lookup_type );
# Move everything below us up
- my $sort_order = $self->SortOrder;
+ my $sort_order = $self->sort_order;
while ( my $OCF = $ObjectCFs->next ) {
- my $this_order = $OCF->SortOrder;
+ my $this_order = $OCF->sort_order;
next if $this_order <= $sort_order;
- $OCF->set_SortOrder( $this_order - 1 );
+ $OCF->set_sort_order( $this_order - 1 );
}
$self->SUPER::delete;
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomFieldValue.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomFieldValue.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/ObjectCustomFieldValue.pm Tue Jan 29 17:41:27 2008
@@ -136,7 +136,7 @@
sub large_content {
my $self = shift;
- return $self->_decode_lob( $self->content_type, $self->ContentEncoding,
+ return $self->_decode_lob( $self->content_type, $self->content_encoding,
$self->_value( 'LargeContent', decode_utf8 => 0 ) );
}
@@ -271,7 +271,7 @@
sub link_value_to {
my $self = shift;
return $self->_fill_in_template_url(
- $self->custom_field_obj->LinkValueTo );
+ $self->custom_field_obj->link_value_to );
}
=head2 ValueIncludeURL
@@ -285,7 +285,7 @@
sub include_content_for_value {
my $self = shift;
return $self->_fill_in_template_url(
- $self->custom_field_obj->IncludeContentForValue );
+ $self->custom_field_obj->include_content_for_value );
}
1;
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Principal.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Principal.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Principal.pm Tue Jan 29 17:41:27 2008
@@ -348,7 +348,7 @@
unshift @{ $args{'equiv_objects'} }, RT->system
unless $self->can('_IsOverrideGlobalACL')
- && $self->_IsOverrideGlobalACL( $args{'Object'} );
+ && $self->_is_override_global_acl( $args{'Object'} );
# {{{ If we've cached a win or loss for this lookup say so
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Queue.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Queue.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Queue.pm Tue Jan 29 17:41:27 2008
@@ -729,7 +729,7 @@
}
} else {
Jifty->log->warn("$self -> AddWatcher got passed a bogus type");
- return ( 0, _('Error in parameters to Queue->AddWatcher') );
+ return ( 0, _('Error in parameters to Queue->add_watcher') );
}
}
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Scrip.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Scrip.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Scrip.pm Tue Jan 29 17:41:27 2008
@@ -251,7 +251,7 @@
#TODO: why are we loading Actions with templates like this.
# two separate methods might make more sense
$self->{'ScripActionObj'}
- ->load( $self->ScripAction, $self->Template );
+ ->load( $self->scrip_action, $self->template );
}
return ( $self->{'ScripActionObj'} );
}
@@ -270,7 +270,7 @@
my $self = shift;
my $res = RT::Model::ScripCondition->new;
- $res->load( $self->ScripCondition );
+ $res->load( $self->scrip_condition );
return $res;
}
@@ -290,7 +290,7 @@
unless ( defined $self->{'template_obj'} ) {
require RT::Model::Template;
$self->{'template_obj'} = RT::Model::Template->new;
- $self->{'template_obj'}->load( $self->Template );
+ $self->{'template_obj'}->load( $self->template );
}
return ( $self->{'template_obj'} );
}
@@ -314,7 +314,7 @@
=cut
-# XXX TODO : This code appears to be obsoleted in favor of similar code in Scrips->Apply.
+# XXX TODO : This code appears to be obsoleted in favor of similar code in Scrips->apply.
# Why is this here? Is it still called?
sub apply {
@@ -415,16 +415,16 @@
my @Transactions;
- if ( $self->Stage eq 'TransactionCreate' ) {
+ if ( $self->stage eq 'TransactionCreate' ) {
# Only look at our current Transaction
@Transactions = ( $args{'transaction_obj'} );
- } elsif ( $self->Stage eq 'transaction_batch' ) {
+ } elsif ( $self->stage eq 'transaction_batch' ) {
# Look at all Transactions in this Batch
@Transactions = @{ $args{'ticket_obj'}->transaction_batch || [] };
} else {
- Jifty->log->error( "Unknown Scrip stage:" . $self->Stage );
+ Jifty->log->error( "Unknown Scrip stage:" . $self->stage );
return (undef);
}
my $ConditionObj = $self->condition_obj;
@@ -492,7 +492,7 @@
. $self->id
. " died. - "
. $err . " "
- . $self->action_obj->ExecModule );
+ . $self->action_obj->exec_module );
return (undef);
}
return ($return);
@@ -548,7 +548,7 @@
unless ( $self->current_user_has_right('ModifyScrips') ) {
Jifty->log->debug(
- "CurrentUser can't modify Scrips for " . $self->Queue . "\n" );
+ "CurrentUser can't modify Scrips for " . $self->queue . "\n" );
return ( 0, _('Permission Denied') );
}
return $self->__set(@_);
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripAction.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripAction.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripAction.pm Tue Jan 29 17:41:27 2008
@@ -167,7 +167,7 @@
$self->{_ticket_obj} = $args{ticket_obj};
#TODO: Put this in an eval
- $self->ExecModule =~ /^(\w+)$/;
+ $self->exec_module =~ /^(\w+)$/;
my $module = $1;
my $type = "RT::ScripAction::" . $module;
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripCondition.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripCondition.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/ScripCondition.pm Tue Jan 29 17:41:27 2008
@@ -168,7 +168,7 @@
);
#TODO: Put this in an eval
- $self->ExecModule =~ /^(\w+)$/;
+ $self->exec_module =~ /^(\w+)$/;
my $module = $1;
my $type = "RT::Condition::" . $module;
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/TemplateCollection.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/TemplateCollection.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/TemplateCollection.pm Tue Jan 29 17:41:27 2008
@@ -183,7 +183,7 @@
# If it's part of a queue, and the user can read templates in
# that queue, or the user can globally read templates, show it
- if ( $templ->Queue
+ if ( $templ->queue
&& $templ->current_user_has_queue_right('ShowTemplate')
or $templ->current_user->has_right(
Object => RT->system,
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Ticket.pm Tue Jan 29 17:41:27 2008
@@ -247,11 +247,11 @@
}
#If we're merged, resolve the merge.
- if ( ( $self->EffectiveId ) and ( $self->EffectiveId != $self->id ) ) {
+ if ( ( $self->effective_id ) and ( $self->effective_id != $self->id ) ) {
Jifty->log->debug( "We found a merged ticket."
. $self->id . "/"
- . $self->EffectiveId );
- return ( $self->load( $self->EffectiveId ) );
+ . $self->effective_id );
+ return ( $self->load( $self->effective_id ) );
}
#Ok. we're loaded. lets get outa here.
@@ -421,7 +421,7 @@
my $Due = RT::Date->new();
if ( defined $args{'Due'} ) {
$Due->set( Format => 'ISO', value => $args{'Due'} );
- } elsif ( my $due_in = $queue_obj->DefaultDueIn ) {
+ } elsif ( my $due_in = $queue_obj->default_due_in ) {
$Due->set_to_now;
$Due->add_days($due_in);
}
@@ -1178,7 +1178,7 @@
}
} else {
Jifty->log->warn("AddWatcher got passed a bogus type");
- return ( 0, _('Error in parameters to Ticket->AddWatcher') );
+ return ( 0, _('Error in parameters to Ticket->add_watcher') );
}
return $self->_add_watcher(%args);
@@ -1905,7 +1905,7 @@
my $time = RT::Date->new();
# -1 is RT::Date slang for never
- if ( my $due = $self->Due ) {
+ if ( my $due = $self->due ) {
$time->set( Format => 'sql', value => $due );
} else {
$time->set( Format => 'unix', value => -1 );
@@ -1943,7 +1943,7 @@
my $self = shift;
my $time = RT::Date->new();
- $time->set( Format => 'sql', value => $self->Resolved );
+ $time->set( Format => 'sql', value => $self->resolved );
return $time;
}
@@ -2007,7 +2007,7 @@
my $self = shift;
my $time = RT::Date->new();
- $time->set( Format => 'sql', value => $self->Started );
+ $time->set( Format => 'sql', value => $self->started );
return $time;
}
@@ -2045,7 +2045,7 @@
my $self = shift;
my $time = RT::Date->new();
- $time->set( Format => 'sql', value => $self->Told );
+ $time->set( Format => 'sql', value => $self->told );
return $time;
}
@@ -2063,7 +2063,7 @@
sub told_as_string {
my $self = shift;
- if ( $self->Told ) {
+ if ( $self->told ) {
return $self->told_obj->as_string();
} else {
return ("Never");
@@ -2333,7 +2333,7 @@
);
$Tickets->limit(
column => 'EffectiveId',
- value => $self->EffectiveId
+ value => $self->effective_id
);
while ( my $Ticket = $Tickets->next ) {
$self->{"$field$type"}->limit(
@@ -2673,26 +2673,26 @@
my %old_seen;
while ( my $link = $old_links_to->next ) {
- if ( exists $old_seen{ $link->Base . "-" . $link->type} ) {
+ if ( exists $old_seen{ $link->base . "-" . $link->type} ) {
$link->delete;
- } elsif ( $link->Base eq $MergeInto->uri ) {
+ } elsif ( $link->base eq $MergeInto->uri ) {
$link->delete;
} else {
# First, make sure the link doesn't already exist. then move it over.
my $tmp = RT::Model::Link->new( current_user => RT->system_user );
$tmp->load_by_cols(
- Base => $link->Base,
+ Base => $link->base,
type => $link->type,
LocalTarget => $MergeInto->id
);
if ( $tmp->id ) {
$link->delete;
} else {
- $link->set_Target( $MergeInto->uri );
- $link->set_LocalTarget( $MergeInto->id );
+ $link->set_target( $MergeInto->uri );
+ $link->set_local_target( $MergeInto->id );
}
- $old_seen{ $link->Base . "-" . $link->type} = 1;
+ $old_seen{ $link->base . "-" . $link->type} = 1;
}
}
@@ -2702,26 +2702,26 @@
$old_links_from->limit( column => 'Base', value => $self->uri );
while ( my $link = $old_links_from->next ) {
- if ( exists $old_seen{ $link->type. "-" . $link->Target } ) {
+ if ( exists $old_seen{ $link->type. "-" . $link->target } ) {
$link->delete;
}
- if ( $link->Target eq $MergeInto->uri ) {
+ if ( $link->target eq $MergeInto->uri ) {
$link->delete;
} else {
# First, make sure the link doesn't already exist. then move it over.
my $tmp = RT::Model::Link->new( current_user => RT->system_user );
$tmp->load_by_cols(
- Target => $link->Target,
+ Target => $link->target,
type => $link->type,
LocalBase => $MergeInto->id
);
if ( $tmp->id ) {
$link->delete;
} else {
- $link->set_Base( $MergeInto->uri );
- $link->set_LocalBase( $MergeInto->id );
- $old_seen{ $link->type. "-" . $link->Target } = 1;
+ $link->set_base( $MergeInto->uri );
+ $link->set_local_base( $MergeInto->id );
+ $old_seen{ $link->type. "-" . $link->target } = 1;
}
}
@@ -2752,7 +2752,7 @@
my ( $val, $msg ) = $MergeInto->_add_watcher(
type => $addwatcher_type,
Silent => 1,
- principal_id => $watcher->MemberId
+ principal_id => $watcher->member_id
);
unless ($val) {
Jifty->log->warn($msg);
@@ -3297,7 +3297,7 @@
my $uid = $self->current_user->id;
my $attr = $self->first_attribute( "User-" . $uid . "-SeenUpTo" );
- return if $attr && $attr->content gt $self->LastUpdated;
+ return if $attr && $attr->content gt $self->last_updated;
my $txns = $self->transactions;
$txns->limit( column => 'type', value => 'comment' );
@@ -3474,7 +3474,7 @@
my $column = shift;
#if the column is public, return it.
- if (1) { # $self->_Accessible( $column, 'public' ) ) {
+ if (1) { # $self->_accessible( $column, 'public' ) ) {
#Jifty->log->debug("Skipping ACL check for $column\n");
return ( $self->SUPER::_value($column) );
@@ -3673,7 +3673,7 @@
my $field = shift;
if ( $field and $field !~ /^\d+$/ ) {
my $cf = RT::Model::CustomField->new;
- $cf->load_by_name_and_queue( name => $field, Queue => $self->Queue );
+ $cf->load_by_name_and_queue( name => $field, Queue => $self->queue );
unless ( $cf->id ) {
$cf->load_by_name_and_queue( name => $field, Queue => 0 );
}
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/TicketCollection.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/TicketCollection.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/TicketCollection.pm Tue Jan 29 17:41:27 2008
@@ -2394,9 +2394,9 @@
}
my $q = "";
- if ( $CF->Queue ) {
+ if ( $CF->queue ) {
my $qo = RT::Model::Queue->new();
- $qo->load( $CF->Queue );
+ $qo->load( $CF->queue );
$q = $qo->name;
}
@@ -2499,7 +2499,7 @@
while ( my $item = $self->next ) {
push( @{ $self->{'items_array'} }, $item );
}
- $self->GotoItem($placeholder);
+ $self->goto_item($placeholder);
$self->{'items_array'}
= $self->items_order_by( $self->{'items_array'} );
}
@@ -2809,12 +2809,12 @@
delete $self->{'item_map'};
if ( $items->[0] ) {
- $self->{'item_map'}->{'first'} = $items->[0]->EffectiveId;
+ $self->{'item_map'}->{'first'} = $items->[0]->effective_id;
while ( my $item = shift @$items ) {
- my $id = $item->EffectiveId;
+ my $id = $item->effective_id;
$self->{'item_map'}->{$id}->{'defined'} = 1;
$self->{'item_map'}->{$id}->{prev} = $prev;
- $self->{'item_map'}->{$id}->{next} = $items->[0]->EffectiveId
+ $self->{'item_map'}->{$id}->{next} = $items->[0]->effective_id
if ( $items->[0] );
$prev = $id;
}
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm Tue Jan 29 17:41:27 2008
@@ -868,7 +868,7 @@
},
subject => sub {
my $self = shift;
- return _( "subject changed to %1", $self->Data );
+ return _( "subject changed to %1", $self->data );
},
AddLink => sub {
my $self = shift;
@@ -898,7 +898,7 @@
return _( "Merged into %1", $value );
}
} else {
- return ( $self->Data );
+ return ( $self->data );
}
},
delete_link => sub {
@@ -928,7 +928,7 @@
return _( "Member %1 deleted", $value );
}
} else {
- return ( $self->Data );
+ return ( $self->data );
}
},
Set => sub {
@@ -968,7 +968,7 @@
},
PurgeTransaction => sub {
my $self = shift;
- return _( "Transaction %1 purged", $self->Data );
+ return _( "Transaction %1 purged", $self->data );
},
AddReminder => sub {
my $self = shift;
@@ -1056,7 +1056,7 @@
=head2 current_user_has_right RIGHT
-Calls $self->current_user->HasQueueRight for the right passed in here.
+Calls $self->current_user->has_queue_right for the right passed in here.
passed in here.
=cut
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm Tue Jan 29 17:41:27 2008
@@ -981,7 +981,7 @@
#If the field is marked as an "administrators only" field,
# don\'t let the user touch it.
- elsif (0) { # $self->_Accessible( $right, 'admin' ) ) {
+ elsif (0) { # $self->_accessible( $right, 'admin' ) ) {
return (undef);
}
@@ -1442,7 +1442,7 @@
if $tmp{'exit_code'} || !$tmp{'info'};
}
- my ( $status, $msg ) = $self->setAttribute(
+ my ( $status, $msg ) = $self->set_attribute(
name => 'private_key',
Content => $key,
);
More information about the Rt-commit
mailing list
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/CachedGroupMember.pm (original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/CachedGroupMember.pm Tue Jan 29 17:41:27 2008
@@ -8,10 +8,10 @@
use Jifty::DBI::Schema;
use Jifty::DBI::Record schema {
- column GroupId => references RT::Model::Group;
- column MemberId => type is 'integer';
- column Via => type is 'integer';
- column ImmediateParentId => type is 'integer';
+ column group_id => references RT::Model::Group;
+ column member_id => type is 'integer';
+ column via => type is 'integer';
+ column immediate_parent_id => type is 'integer';
column disabled => type is 'integer', default is '0';
};
@@ -45,7 +45,7 @@
'ImmediateParent' is the RT::Model::Principal of the group that this
principal belongs to to get here
- int(11) 'Via' is an internal reference to CachedGroupMembers->id of
+ int(11) 'via' is an internal reference to CachedGroupMembers->id of
the "parent" record of this cached group member. It should be empty if
this member is a "direct" member of this group. (In that case, it will
be set to this cached group member's id after creation)
@@ -62,7 +62,7 @@
Group => '',
Member => '',
ImmediateParent => '',
- Via => '0',
+ via => '0',
disabled => '0',
@_
);
@@ -94,11 +94,11 @@
}
my $id = $self->SUPER::create(
- GroupId => $args{'Group'}->id,
- MemberId => $args{'Member'}->id,
- ImmediateParentId => $args{'ImmediateParent'}->id,
+ group_id => $args{'Group'}->id,
+ member_id => $args{'Member'}->id,
+ immediate_parent_id => $args{'ImmediateParent'}->id,
disabled => $args{'disabled'},
- Via => $args{'Via'},
+ via => $args{'via'},
);
unless ($id) {
@@ -106,18 +106,18 @@
. $args{'Member'}
. " as a cached member of "
. $args{'Group'}->id . " via "
- . $args{'Via'} );
+ . $args{'via'} );
return (undef)
; #this will percolate up and bail out of the transaction
}
- if ( $self->__value('Via') == 0 ) {
- my ( $vid, $vmsg ) = $self->__set( column => 'Via', value => $id );
+ if ( $self->__value('via') == 0 ) {
+ my ( $vid, $vmsg ) = $self->__set( column => 'via', value => $id );
unless ($vid) {
Jifty->log->warn( "Due to a via error, couldn't create "
. $args{'Member'}
. " as a cached member of "
. $args{'Group'}->id . " via "
- . $args{'Via'} );
+ . $args{'via'} );
return (undef)
; #this will percolate up and bail out of the transaction
}
@@ -132,7 +132,7 @@
Member => $member->member_obj,
ImmediateParent => $args{'Member'},
disabled => $args{'disabled'},
- Via => $id
+ via => $id
);
unless ($c_id) {
return (undef); #percolate the error upwards.
@@ -171,7 +171,7 @@
value => $self->id
);
$deletable->limit(
- column => 'Via',
+ column => 'via',
operator => '=',
value => $self->id
);
@@ -193,7 +193,7 @@
unless ( $self->group_obj->object ) {
- warn "HEY! NO group object object!!!" . $self->__value('GroupId');
+ warn "HEY! NO group object object!!!" . $self->__value('group_id');
warn YAML::Dump($self);
use YAML;
return undef;
@@ -202,13 +202,13 @@
# Unless $self->group_obj still has the member recursively $self->member_obj
# (Since we deleted the database row above, $self no longer counts)
unless (
- $self->group_obj->object->has_member_recursively( $self->MemberId ) )
+ $self->group_obj->object->has_member_recursively( $self->member_id ) )
{
# Find all ACEs granted to $self->GroupId
my $acl = RT::Model::ACECollection->new(
current_user => RT->system_user );
- $acl->limit_to_principal( id => $self->GroupId );
+ $acl->limit_to_principal( id => $self->group_id );
while ( my $this_ace = $acl->next() ) {
@@ -216,7 +216,7 @@
my $delegations = RT::Model::ACECollection->new(
current_user => RT->system_user );
$delegations->delegated_from( id => $this_ace->id );
- $delegations->delegated_by( id => $self->MemberId );
+ $delegations->delegated_by( id => $self->member_id );
# For each delegation
while ( my $delegation = $delegations->next ) {
@@ -267,7 +267,7 @@
my $deletable = RT::Model::CachedGroupMemberCollection->new;
$deletable->limit(
- column => 'Via',
+ column => 'via',
operator => '=',
value => $self->id
);
@@ -290,13 +290,13 @@
# Unless $self->group_obj still has the member recursively $self->member_obj
# (Since we Setdisabledd the database row above, $self no longer counts)
unless (
- $self->group_obj->object->has_member_recursively( $self->MemberId ) )
+ $self->group_obj->object->has_member_recursively( $self->member_id ) )
{
# Find all ACEs granted to $self->GroupId
my $acl = RT::Model::ACECollection->new(
current_user => RT->system_user );
- $acl->limit_to_principal( id => $self->GroupId );
+ $acl->limit_to_principal( id => $self->group_id );
while ( my $this_ace = $acl->next() ) {
@@ -304,7 +304,7 @@
my $delegations = RT::Model::ACECollection->new(
current_user => RT->system_user );
$delegations->delegated_from( id => $this_ace->id );
- $delegations->delegated_by( id => $self->MemberId );
+ $delegations->delegated_by( id => $self->member_id );
# For each delegation, blow away the delegation
while ( my $delegation = $delegations->next ) {
@@ -336,7 +336,7 @@
sub group_obj {
my $self = shift;
my $principal = RT::Model::Principal->new;
- $principal->load( $self->GroupId );
+ $principal->load( $self->group_id );
return ($principal);
}
@@ -353,7 +353,7 @@
sub immediate_parent_obj {
my $self = shift;
my $principal = RT::Model::Principal->new;
- $principal->load( $self->ImmediateParentId );
+ $principal->load( $self->immediate_parent_id );
return ($principal);
}
@@ -370,7 +370,7 @@
sub member_obj {
my $self = shift;
my $principal = RT::Model::Principal->new;
- $principal->load( $self->MemberId );
+ $principal->load( $self->member_id );
return ($principal);
}
Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/CustomField.pm
@@ -202,13 +202,13 @@
{
- # Find all ACEs granted to $self->GroupId
+ # Find all ACEs granted to $self->group_id
my $acl = RT::Model::ACECollection->new(
current_user => RT->system_user );
@@ -290,13 +290,13 @@
{
- # Find all ACEs granted to $self->GroupId
+ # Find all ACEs granted to $self->group_id
my $acl = RT::Model::ACECollection->new(
current_user => RT->system_user );
==============================================================================